``saltext-mysql``: Integrate Salt with Mysql
============================================

Salt Extension for interacting with MySQL

.. toctree::
  :maxdepth: 2
  :caption: Guides
  :hidden:

  topics/installation

.. toctree::
  :maxdepth: 2
  :caption: Provided Modules
  :hidden:

  ref/auth/index
  ref/cache/index
  ref/modules/index
  ref/pillar/index
  ref/returners/index
  ref/states/index

.. toctree::
  :maxdepth: 2
  :caption: Reference
  :hidden:

  changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
